@@ -10,14 +10,14 @@ class test_bookmarks(common.basetest):
         self.append('a', 'a')
         rev1, node1 = self.client.commit('second')
 
-        self.client.bookmark('0', rev0)
+        self.client.bookmark('zero', rev0)
         self.assertEquals(self.client.bookmarks(),
-                          ([('0', rev0, node0[:12])], -1))
+                          ([('zero', rev0, node0[:12])], -1))
 
-        self.client.bookmark('1', rev1)
+        self.client.bookmark('one', rev1)
         self.assertEquals(self.client.bookmarks(),
-                          ([('0', rev0, node0[:12]),
-                            ('1', rev1, node1[:12])], 1))
+                          ([('one', rev1, node1[:12]),
+                            ('zero', rev0, node0[:12])], 0))
 
     #def test_spaces(self):
     #    self.client.bookmark('s pace', self.rev0)
